module.exports = defineTest({
	description: 'Track side-effects of method return values'
});
